---
Summary: Modify sphinx doco to generate output from examples
Status: Ready
Tags:
    - Tech Debt
---

# Description

The tutorial and sphinx documentation shows a number of examples of command
line usage of ScrumMD with the output of those commands manually added. This
means that they won't be consistent with changes.

This card is to change all of those references to actually run the various CLI
utilities to provide examples of their output when doco is generated.
